@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 # autogen.sh glue for pxlib
-# $Id: autogen.sh,v 1.9 2007/09/12 15:31:50 steinm Exp $
+# $Id: autogen.sh,v 1.10 2015/12/27 06:52:34 steinm Exp $
 #
 # Requires: automake, autoconf, dpkg-dev
 set -e
@@ -35,7 +35,7 @@ test -d debian && {
 	# for whatever reason.
 	echo Generating list of executable files...
 	rm -f debian/executable.files
-	find -type f -perm +111 ! -name '.*' -fprint debian/executable.files
+	find -type f -perm /111 ! -name '.*' -fprint debian/executable.files
 
 	# link these in Debian builds
 #	rm -f config.sub config.guess
