@@ -87,7 +87,7 @@ pxstream_t *px_stream_new_file(pxdoc_t *pxdoc, int mode, int close, FILE *fp) {
  * It calls the read function from px_stream_t to actually get the
  * file data.
  */
-size_t px_read(pxdoc_t *p, pxstream_t *dummy, size_t len, void *buffer) {
+ssize_t px_read(pxdoc_t *p, pxstream_t *dummy, size_t len, void *buffer) {
 	size_t ret;
 	long blocknr, blockpos, curpos, blocksize;
 	pxhead_t *pxh;
@@ -100,7 +100,7 @@ size_t px_read(pxdoc_t *p, pxstream_t *dummy, size_t len, void *buffer) {
 	if(pxh != NULL && curpos >= pxh->px_headersize) {
 		blocksize = pxh->px_maxtablesize * 0x400;
 		blocknr = ((curpos - pxh->px_headersize) / blocksize) + 1;
-		blockpos = (curpos - pxh->px_headersize) % blocksize; 
+		blockpos = (curpos - pxh->px_headersize) % blocksize;
 //		fprintf(stderr, "reading from block %d:%d\n", blocknr, blockpos);
 		if(blockpos+len > blocksize) {
 			px_error(p, PX_RuntimeError, _("Trying to read data from file exceeds block boundary."));
@@ -161,7 +161,7 @@ long px_tell(pxdoc_t *p, pxstream_t *dummy) {
 
 /* px_write() {{{
  */
-size_t px_write(pxdoc_t *p, pxstream_t *dummy, size_t len, void *buffer) {
+ssize_t px_write(pxdoc_t *p, pxstream_t *dummy, size_t len, void *buffer) {
 	size_t ret;
 	long blocknr, blockpos, curpos, blocksize;
 	pxhead_t *pxh;
@@ -258,7 +258,7 @@ int px_flush(pxdoc_t *p, pxstream_t *dummy) {
  * file data.
  */
 #define BLOCKSIZEEXP 8 /* Each encrypted block has 2^BLOCKSIZEEXP bytes */
-size_t px_mb_read(pxblob_t *p, pxstream_t *dummy, size_t len, void *buffer) {
+ssize_t px_mb_read(pxblob_t *p, pxstream_t *dummy, size_t len, void *buffer) {
 	pxdoc_t *pxdoc;
 	pxhead_t *pxh;
 	pxstream_t *pxs;
@@ -364,7 +364,7 @@ long px_mb_tell(pxblob_t *p, pxstream_t *dummy) {
 
 /* px_mb_write() {{{
  */
-size_t px_mb_write(pxblob_t *p, pxstream_t *dummy, size_t len, void *buffer) {
+ssize_t px_mb_write(pxblob_t *p, pxstream_t *dummy, size_t len, void *buffer) {
 	return(p->mb_stream->write(p->pxdoc, p->mb_stream, len, buffer));
 }
 /* }}} */
@@ -372,7 +372,7 @@ size_t px_mb_write(pxblob_t *p, pxstream_t *dummy, size_t len, void *buffer) {
 /* regular file pointer */
 /* px_fread() {{{
  */
-size_t px_fread(pxdoc_t *p, pxstream_t *stream, size_t len, void *buffer) {
+ssize_t px_fread(pxdoc_t *p, pxstream_t *stream, size_t len, void *buffer) {
 	return(fread(buffer, 1, len, stream->s.fp));
 }
 /* }}} */
@@ -393,7 +393,7 @@ long px_ftell(pxdoc_t *p, pxstream_t *stream) {
 
 /* px_fwrite() {{{
  */
-size_t px_fwrite(pxdoc_t *p, pxstream_t *stream, size_t len, void *buffer) {
+ssize_t px_fwrite(pxdoc_t *p, pxstream_t *stream, size_t len, void *buffer) {
 	return(fwrite(buffer, 1, len, stream->s.fp));
 }
 /* }}} */
@@ -402,7 +402,7 @@ size_t px_fwrite(pxdoc_t *p, pxstream_t *stream, size_t len, void *buffer) {
 #if HAVE_GSF
 /* px_gsfread() {{{
  */
-size_t px_gsfread(pxdoc_t *p, pxstream_t *stream, size_t len, void *buffer) {
+ssize_t px_gsfread(pxdoc_t *p, pxstream_t *stream, size_t len, void *buffer) {
 	return((int) gsf_input_read(stream->s.gsfin, len, buffer));
 }
 /* }}} */
@@ -430,7 +430,7 @@ long px_gsftell(pxdoc_t *p, pxstream_t *stream) {
 
 /* px_gsfwrite() {{{
  */
-size_t px_gsfwrite(pxdoc_t *p, pxstream_t *stream, size_t len, void *buffer) {
+ssize_t px_gsfwrite(pxdoc_t *p, pxstream_t *stream, size_t len, void *buffer) {
 	return(gsf_output_write(stream->s.gsfout, len, buffer));
 }
 /* }}} */
