@@ -5,7 +5,9 @@
  *
  * This file was taken from the php source code ext/dbase/db_misc.c
  */
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
@@ -14,6 +16,13 @@
 
 #include "px_misc.h"
 
+#ifdef WIN32
+#define localtime_r( _clock, _result ) \
+	( *(_result) = *localtime( (_clock) ), \
+	(_result) )
+
+#endif
+
 /*
  * routine to change little endian long to host long
  * these functions are used read header data
